NAME

Crypt::PBKDF2::Hash::DigestHMAC - Digest::HMAC hash support for Crypt::PBKDF2.

VERSION

version 0.261630

DESCRIPTION

Uses Digest::HMAC to make nearly any Digest-compatible module compatible with Crypt::PBKDF2 by driving it with the standard HMAC algorithm to combine the key and the data.

ATTRIBUTES

digest_class

The Digest class to use. Will be passed to Digest->new.

AUTHOR

Andrew Rodland <andrew@cleverdomain.org>

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Andrew Rodland.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.